@@ -6,7 +6,7 @@
 ;; Keywords: languages
 ;; URL: https://github.com/openscad/emacs-scad-mode
 ;; Package-Requires: ((emacs "28.1") (compat "30"))
-;; Version: 96.0
+;; Version: 97.0
 
 ;; This file is not part of GNU Emacs.
 
@@ -406,6 +406,7 @@ Options are .stl, .off, .amf, .3mf, .csg, .dxf, .svg, .pdf, .png,
   (add-hook 'kill-buffer-hook #'scad--preview-kill nil 'local)
   (add-hook 'kill-buffer-hook #'scad--preview-delete nil 'local)
   (add-hook 'window-size-change-functions
+            ;; TODO On Emacs 31 `window-size-change-functions' run in the current buffer
             (let ((buf (current-buffer)))
               (lambda (_)
                 (with-current-buffer buf
@@ -494,9 +495,5 @@ Options are .stl, .off, .amf, .3mf, .csg, .dxf, .svg, .pdf, .png,
               (delete-file infile)
               (kill-buffer (process-buffer proc))))))))))
 
-;; Print warning if the scad-preview package is installed
-(when (require 'scad-preview nil 'noerror)
-  (warn "The scad-preview package should be removed, it has been merged into scad-mode"))
-
 (provide 'scad-mode)
 ;;; scad-mode.el ends here
